aboutsummaryrefslogtreecommitdiff
path: root/engines/saga/displayinfo.h
diff options
context:
space:
mode:
authorEugene Sandulenko2008-09-24 22:44:01 +0000
committerEugene Sandulenko2008-09-24 22:44:01 +0000
commit84379f1124bd68a228e83219bc57b0f56fffd5f5 (patch)
tree806b5bfbc391e5a54dc0cefbe7cb3563f45333f8 /engines/saga/displayinfo.h
parenta408f4a7761e76724f552e93a075409a609b94d3 (diff)
downloadscummvm-rg350-84379f1124bd68a228e83219bc57b0f56fffd5f5.tar.gz
scummvm-rg350-84379f1124bd68a228e83219bc57b0f56fffd5f5.tar.bz2
scummvm-rg350-84379f1124bd68a228e83219bc57b0f56fffd5f5.zip
Fix bugs #1981081: "ITE: No blinking disk icon" and #1971729: "IHNM: No Animation of Disk Icon"
svn-id: r34645
Diffstat (limited to 'engines/saga/displayinfo.h')
-rw-r--r--engines/saga/displayinfo.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/engines/saga/displayinfo.h b/engines/saga/displayinfo.h
index 3775e904ff..c85b5b830f 100644
--- a/engines/saga/displayinfo.h
+++ b/engines/saga/displayinfo.h
@@ -64,7 +64,7 @@ struct GameDisplayInfo {
int saveReminderWidth;
int saveReminderHeight;
int saveReminderFirstSpriteNumber;
- int saveReminderSecondSpriteNumber;
+ int saveReminderNumSprites;
int leftPortraitXOffset;
int leftPortraitYOffset;
@@ -230,7 +230,8 @@ static const GameDisplayInfo ITE_DisplayInfo = {
15, // status BG color
308,137, // save reminder pos
12,12, // save reminder w & h
- 6,7, // save reminder sprite numbers
+ 6, // save reminder first sprite number
+ 2, // number of save reminder sprites
5, 4, // left portrait x, y offset
274, 4, // right portrait x, y offset
@@ -376,7 +377,8 @@ static const GameDisplayInfo IHNM_DisplayInfo = {
250, // status BG color
616, 304, // save reminder pos
24, 24, // save reminder w&h
- 0,1, // save reminder sprite numbers
+ 0, // save reminder first sprite number
+ 16, // number of save reminder sprites
11, 12, // left portrait x, y offset
-1, -1, // right portrait x, y offset